% Copyright (c) Camden Dixie O'Brien
% SPDX-License-Identifier: AGPL-3.0-only

-module(subject_server).
-behaviour(gen_server).

-export([start_link/1]).
-export([init/1, handle_call/3, handle_cast/2, handle_info/2,
		 terminate/2, code_change/3]).

start_link(Subject) ->
	gen_server:start_link(?MODULE, Subject, []).

init(Subject) ->
	pg:join(study_system_server, subject_servers, self()),
	{ok, #{subject => Subject}}.

handle_call(get_subject, _From, State = #{subject := Subject}) ->
	{reply, {subject, Subject}, State};
handle_call(_Request, _From, State) ->
	{reply, ok, State}.

handle_cast(_Msg, State) ->
	{noreply, State}.

handle_info({new_session, Type, Timestamp, Minutes},
			State = #{subject := Subject}) ->
	io:format(
	  "Received new ~p session: type ~p, timestamp ~p, minutes ~p~n",
	  [Subject, Type, Timestamp, Minutes]),
	{noreply, State};
handle_info(_Info, State) ->
	{noreply, State}.

terminate(_Reason, _State) ->
	ok.

code_change(_OldVsn, State, _Extra) ->
	{ok, State}.
